#
# spec file for package GeoIP
#
# Copyright (c) 2008 SUSE LINUX Products GmbH, Nuernberg, Germany.
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#
# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild
%define pkgname	GeoIP
%define updatepkgname geoipupdate
%define updatepkgver 2.2.1

Name:           GeoIP
Version:        1.6.5
Release:        17.1
#
License:        LGPL v2.1 or later
Group:          Development/Libraries/C and C++
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  zlib-devel curl-devel
BuildRequires:	autoconf automake
#
Url:            http://www.maxmind.com/
Source:		http://www.maxmind.com/download/geoip/api/c/%{pkgname}-%{version}.tar.bz2
Source1:        LICENSE.txt
Source2:	GeoIP.dat.gz
Source3:	%{updatepkgname}-%{updatepkgver}.tar.bz2
#
Summary:        Library to find the country that any IP address originates from

%description
GeoIP is a C library that enables the user to find the country that any
IP address or hostname originates from.  It uses a file based database.
 This database simply contains IP blocks as keys, and countries as
values.  This database should be more complete and accurate than using
reverse DNS lookups.

MaxMind offers a service where you can have your database updated
automically each month.



Authors:
--------
    T.J. Mather <tjmather@maxmind.com>

%package -n libGeoIP1
Group:          Development/Libraries/C and C++
#
Summary:        Shared libraries of the GeoIP C API

%description -n libGeoIP1
GeoIP is a C library that enables the user to find the country that any
IP address or hostname originates from.  It uses a file based database.
This database simply contains IP blocks as keys, and countries as
values.  This database should be more complete and accurate than using
reverse DNS lookups.

MaxMind offers a service where you can have your database updated
automically each month.

This package holds the shared libraries for GeoIP.



Authors:
--------
    T.J. Mather <tjmather@maxmind.com>

%package -n libGeoIP-devel
Group:          Development/Libraries/C and C++
Requires:       libGeoIP1 = %{version}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{name}-devel < %{version}
#
Summary:        Development Files for GeoIP

%description -n libGeoIP-devel
GeoIP is a C library that enables the user to find the country that any
IP address or hostname originates from.  It uses a file based database.
This database simply contains IP blocks as keys, and countries as
values.  This database should be more complete and accurate than using
reverse DNS lookups.

MaxMind offers a service where you can have your database updated
automically each month.

This package holds the development files for GeoIP.



Authors:
--------
    T.J. Mather <tjmather@maxmind.com>

%if 1%{?rhel} == 7
%debug_package
%endif

%prep -
%setup -n %{pkgname}-%{version} -b 3
zcat %{S:2} > data/GeoIP.dat

%build
if [ ! -f configure ] ; then
 if [ -x bootstrap ] ; then
  ./bootstrap
 fi
fi
%configure --disable-static --with-pic
%{__make} %{?jobs:-j%jobs}
cd ../%{updatepkgname}-%{updatepkgver}
if [ ! -f configure ] ; then
 if [ -x bootstrap ] ; then
  ./bootstrap
 fi
fi
%configure --disable-static --with-pic
%{__make} %{?jobs:-j%jobs}

%install
%makeinstall
# we don't need that, we use %config(noreplace) instead
%{__rm} -f %{buildroot}%{_sysconfdir}/GeoIP.conf.default
%{__cp} %{SOURCE1} .
# no need for that
%{__rm} -f %{buildroot}%{_libdir}/*.la
cd ../%{updatepkgname}-%{updatepkgver}
%makeinstall
%{__rm} -f %{buildroot}%{_sysconfdir}/GeoIP.conf.default
%__install -D -m0644 ../%{pkgname}-%{version}/data/GeoIP.dat %{buildroot}%{_datadir}/GeoIP/GeoIP.dat

%clean
%{__rm} -rf %{buildroot}

%post   -n libGeoIP1 -p /sbin/ldconfig

%postun -n libGeoIP1 -p /sbin/ldconfig

%files
%defattr(-, root, root, -)
%doc AUTHORS ChangeLog COPYING LICENSE.txt
%config(noreplace) %{_sysconfdir}/GeoIP.conf
%{_bindir}/geoiplookup
%{_bindir}/geoiplookup6
%{_bindir}/geoipupdate
%dir %{_datadir}/GeoIP
%{_datadir}/GeoIP/GeoIP.dat
%{_mandir}/man1/geoiplookup.1*
%{_mandir}/man1/geoipupdate.1*
%{_mandir}/man1/geoiplookup6.1*
%{_mandir}/man5/GeoIP.conf.5*

%files -n libGeoIP1
%defattr(-, root, root, -)
%{_libdir}/libGeoIP.so.1
%{_libdir}/libGeoIP.so.1.*
##%{_libdir}/libGeoIPUpdate.so.0
##%{_libdir}/libGeoIPUpdate.so.0.0.0

%files -n libGeoIP-devel
%defattr(-, root, root, -)
%{_includedir}/GeoIP.h
%{_includedir}/GeoIPCity.h
##%{_includedir}/GeoIPUpdate.h
%{_libdir}/libGeoIP.so
##%{_libdir}/libGeoIPUpdate.so
%{_libdir}/pkgconfig/geoip.pc

%changelog
* Mon May 18 2015 cs@linux-administrator.com
- update to release 1.6.5
* Wed Jul 23 2014 cs@linux-administrator.com
- update to release 1.5.1
  * Update time_zone for Ontario, Canada ( Boris Zentner )
  * geoiplookup and geoiplookup6 exit code is 0 when user asked for help ( Jan Safranek )
  * Added -h option to geoiplookup6 ( Jan Safranek )
  * Do not load the database file if nodes and file size do not make sense. ( Boris Zentner )
  * Keep README and man pages in pure ascii. ( Boris Zentner )
  * It doesn't make sense to use GEOIP_INDEX_MODE with small databases like GEOIP_COUNTRY_EDITION. Instead of undefined behaviour we handle it silently as GEOIP_MEMORY_MODE ( Boris Zentner )
  * Update FIPS codes for Greece ( Boris Zentner )
- changes from 1.5.0
  * Rename custom_directory to GeoIP_custom_directory. ( Boris Zentner )
  * Make sure the database match the requested type. This is helpful for Databases with the same default name and the general geoiplookup form ( geoiplookup without a specific database ) ( Boris Zentner )
  * apps/geoiplookup6.c use the ipnum instead of the hostname for lookups. ( Boris Zentner )
  * Use configure.ac instead of configure.in ( Boris Zentner )
  * Region lookup is a bit faster ( Boris Zentner )
  * Add pkg-config file ( Bastien Nocera )
  * Updates required to build a Windows DLL under MinGW ( Gerald Combs )
  * Make API thread safe ( Boris Zentner )
  * geoiplookup's default charset is UTF8 -l change the charset back to iso8859-1 ( Boris Zentner )
  * geoipupdate skips \r otherwise it might be part of the last product_id ( Boris Zentner )
  * Update time zones ( Boris Zentner )
  * Update Region codes ( Boris Zentner )
  * Remove the unused CITYCONFIDENCE* database types ( Boris Zentner )
  * bootstrap rebuilds ltmain.sh ( Boris Zentner )
  * Update README.OSX for Lion ( Boris Zentner )
  * Change Macedonia to Macedonia, The Former Yugoslav Republic of ( Boris Zentner )
  * Add region_name to geoiplookup GEOIP_CITY_EDITION_REV1 ( Boris Zentner )
  * Add region_name to geoiplookup GEOIP_CITY_EDITION_REV0 ( Chris Johnson )
  * Add a --disable-data-files option. This allows you to build and install the library without having a data/GeoIP.dat file. This is useful when building the library from a checkout of the source tree, rather than a tarball ( Dave Rolsky )
  * Add GEOIP_ACCURACYRADIUS_EDITION and GEOIP_ACCURACYRADIUS_EDITION_V6 ( Boris Zentner )
  * Add more database types GEOIP_COUNTRYCONF_EDITION, GEOIP_CITYCONF_EDITION, GEOIP_REGIONCONF_EDITION and GEOIP_POSTALCONF_EDITION ( Boris Zentner )
  * Fix default filenames for GEOIP_NETSPEED_EDITION_REV1 and GEOIP_NETSPEED_EDITION_REV1_V6 ( Boris Zentner )
* Fri Dec 16 2011 cs@linux-administrator.com
- update to release 1.4.8
* Mon Oct 20 2008 cs@linux-administrator.com
- new release 1.4.5
* Tue Jan 22 2008 lnussel@suse.de
- new version 1.4.4, breaks ABI wrt GeoIP_country_code!
  * Updated original geoipupdate to return "Invalid product ID or
    subscription expired"
  * Added BL/Saint Barthelemy, MF/Saint Martin (ISO-3166-1
    additions)
  * Check for illegal IP strings, return 0 if IP is not well formed
    IPv4 e.g. 1.2.3.4.5 and 1.2.3
  * Clarified that while core GeoIP library is LGPL, libGeoIPUpdate
    depends on md5.c and types.h which are GPL.
  * speedup the conversion from ipstring to ipnum in
    _GeoIP_addr_to_num. Doubles the speed of GEOIP_MEMORY_CACHE and
    GEOIP_MMAP_CACHE
  * Added new mmap shared memory caching option, GEOIP_MMAP_CACHE
* Tue Oct  9 2007 mrueckert@suse.de
- move the ldconfig calls to the correct package
* Sun Oct  7 2007 mrueckert@suse.de
- new version 1.4.3
  ! CHANGE with geoiplookup facility: -v flag now returns database
    info for all databases, not just GeoIP Country
  * Added ability to get netmask of network block from last lookup
    using GeoIP_last_netmask
  * Fixed GeoIP_database_info bug with GeoLite City
  * Replaced 4 with sizeof(char*) to fix issues with geoipupdate on
    64 Bit machines
  * Added GeoIP_set_charset function - enables UTF8 output of city
    name if GEOIP_CHARSET_UTF8 flag is passed to GeoIP_set_charset
  * Fixed segfault issue if calling GeoIP_db_avail before opening
    a database
  * Added continent_code to GeoIP City's record struct
    (Frank Mather)
- changes to the package layout:
  - splitted out library package (libGeoIP1)
  - renamed devel package GeoIP-devel to libGeoIP-devel
* Wed Aug 29 2007 mrueckert@suse.de
- we dont need zlib-devel to link against libGeoIP
* Wed Aug 29 2007 mrueckert@suse.de
- spec file cleanup
- fix rpmlint warnings
* Wed Aug 29 2007 crrodriguez@suse.de
- run ldconfig
- fix devel package dependencies
* Thu Apr  5 2007 mrueckert@suse.de
- submit the splitted package from the buildservice
* Thu Mar 29 2007 lnussel@suse.de
- new version 1.4.2
  * Replaced CS/Serbia and Montenegro with RS/Serbia, removed
    ZR/Zaire, added ME/Montenegro
  * Added AX/Aland Islands, GG/Guernsey, IM/Isle of Man, JE/Jersey
    (ISO-3166-1 changes)
  * Added GeoIP_time_zone_by_country_and_region(),
    GeoIP_region_name_by_code()
  * Added -d flag to enable custom path for geoipupdate
- don't package *.a and *.la
- add zlib-devel to BuildRequires
* Fri Jan 26 2007 mrueckert@suse.de
- update to version 1.4.1
  * Replaced CS/Serbia and Montenegro with RS/Serbia, removed
    ZR/Zaire, added ME/Montenegro
  * Added AX/Aland Islands, GG/Guernsey, IM/Isle of Man, JE/Jersey
    (ISO-3166-1 changes)
  * Added GeoIP_time_zone_by_country_and_region, to lookup zoneinfo
    timezone by country and region (Frank Mather)
  * Added GeoIP_region_name_by_code, to lookup region name from
    region code (Frank Mather)
  * added -f and -d flags to enable custom paths for geoiplookup
    utility program (Frank Mather)
  * Added benchmarks for GeoIP Region and City in test/benchmark.c
    (Frank Mather)
  * Fixed build issue when using --as-needed flag
    (Diego 'Flameeyes' Pettenò)
  * Add sanity checking for filename returned by MaxMind.com server
    for geoipupdate filename (Dean Gaudet, arctic.org)
  * Fixed memory leaks under error conditions, buffer overflow
    using sprintf, and issue where a corrupted cache file could
    core dump the file (Nick Galbreath, Right Media Inc)
* Fri Dec  8 2006 mrueckert@suse.de
- spec file clean up
- split out the devel files
* Sat Oct 28 2006 lnussel@suse.de
- update to version 1.4.0
  * license change to LGPL
  * various fixes
* Mon May 15 2006 cthiel@suse.de
- update to version 1.3.17
  * Fixed headers for Windows/Netware compliation
  * Updated README documentation
  * Updated geoipupdate so that it writes file as it is uncompressed inst
    of storing entire GeoIP.dat file in memory
  * Updated geoiplookup so that it returns GeoIP Domain Name if available
  * Updated geoipupdate so that it reports whether databases are updated
    in non-verbose mode
  * Fixed compliation error in GeoIPUpdate.c
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep 15 2005 lnussel@suse.de
- new version 1.3.14
* Mon Jul  4 2005 lnussel@suse.de
- fix gcc warnings (#95085)
* Thu Nov 25 2004 lnussel@suse.de
- new version 1.3.8
* Thu Nov 18 2004 ro@suse.de
- fixed file list
* Thu Jul 15 2004 lnussel@suse.de
- new version 1.3.5
- fix missing prototype and a memleak
* Fri Apr 16 2004 lnussel@suse.de
- fix missing return value in main() of some test programs
* Mon Nov 24 2003 lnussel@suse.de
- initial package, version 1.3.1
